@@ -1,7 +1,7 @@
 // qsamplerOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2021, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -36,7 +36,14 @@
 #include <lscp/client.h>
 
 #ifdef CONFIG_LIBGIG
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-parameter"
+#endif
 #include <gig.h>
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
+#pragma GCC diagnostic pop
+#endif
 #endif
 
 
@@ -355,11 +362,11 @@ bool Options::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
-			out << QString("Qt: %1\n")
-				.arg(qVersion());
-			out << QString("%1: %2\n")
-				.arg(QSAMPLER_TITLE)
-				.arg(CONFIG_BUILD_VERSION);
+			out << QString("Qt: %1").arg(qVersion());
+		#if defined(QT_STATIC)
+			out << "-static";
+		#endif
+			out << '\n';
 		#ifdef CONFIG_LIBGIG
 			out << QString("%1: %2\n")
 				.arg(gig::libraryName().c_str())
@@ -368,6 +375,9 @@ bool Options::parse_args ( const QStringList& args )
 			out << QString("%1: %2\n")
 				.arg(::lscp_client_package())
 				.arg(::lscp_client_version());
+			out << QString("%1: %2\n")
+				.arg(QSAMPLER_TITLE)
+				.arg(CONFIG_BUILD_VERSION);
 			return false;
 		}
 		else {
